@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,14 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from google.cloud.gke_backup import gapic_version as package_version
+from google.cloud.gke_backup_v1 import gapic_version as package_version
 
 __version__ = package_version.__version__
 
 
 from .services.backup_for_gke import BackupForGKEAsyncClient, BackupForGKEClient
 from .types.backup import Backup
-from .types.backup_plan import BackupPlan
+from .types.backup_plan import BackupPlan, ExclusionWindow, RpoConfig
 from .types.common import EncryptionKey, NamespacedName, NamespacedNames, Namespaces
 from .types.gkebackup import (
     CreateBackupPlanRequest,
@@ -31,6 +31,8 @@ from .types.gkebackup import (
     DeleteBackupRequest,
     DeleteRestorePlanRequest,
     DeleteRestoreRequest,
+    GetBackupIndexDownloadUrlRequest,
+    GetBackupIndexDownloadUrlResponse,
     GetBackupPlanRequest,
     GetBackupRequest,
     GetRestorePlanRequest,
@@ -73,6 +75,9 @@ __all__ = (
     "DeleteRestorePlanRequest",
     "DeleteRestoreRequest",
     "EncryptionKey",
+    "ExclusionWindow",
+    "GetBackupIndexDownloadUrlRequest",
+    "GetBackupIndexDownloadUrlResponse",
     "GetBackupPlanRequest",
     "GetBackupRequest",
     "GetRestorePlanRequest",
@@ -98,6 +103,7 @@ __all__ = (
     "Restore",
     "RestoreConfig",
     "RestorePlan",
+    "RpoConfig",
     "UpdateBackupPlanRequest",
     "UpdateBackupRequest",
     "UpdateRestorePlanRequest",
