@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,9 +19,7 @@ from typing import Dict, Type
 from .base import BackupForGKETransport
 from .grpc import BackupForGKEGrpcTransport
 from .grpc_asyncio import BackupForGKEGrpcAsyncIOTransport
-from .rest import BackupForGKERestTransport
-from .rest import BackupForGKERestInterceptor
-
+from .rest import BackupForGKERestInterceptor, BackupForGKERestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[BackupForGKETransport]]
