@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@ __protobuf__ = proto.module(
 class Restore(proto.Message):
     r"""Represents both a request to Restore some portion of a Backup
     into a target GKE cluster and a record of the restore operation
-    itself. Next id: 18
+    itself.
 
     Attributes:
         name (str):
@@ -219,7 +219,6 @@ class Restore(proto.Message):
 
 class RestoreConfig(proto.Message):
     r"""Configuration of a restore.
-    Next id: 9
 
     This message has `oneof`_ fields (mutually exclusive fields).
     For each oneof, at most one member field can be set at the same time.
@@ -230,25 +229,26 @@ class RestoreConfig(proto.Message):
 
     Attributes:
         volume_data_restore_policy (google.cloud.gke_backup_v1.types.RestoreConfig.VolumeDataRestorePolicy):
-            Specifies the mechanism to be used to restore volume data.
-            Default: VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED (will be
-            treated as NO_VOLUME_DATA_RESTORATION).
+            Optional. Specifies the mechanism to be used to restore
+            volume data. Default: VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED
+            (will be treated as NO_VOLUME_DATA_RESTORATION).
         cluster_resource_conflict_policy (google.cloud.gke_backup_v1.types.RestoreConfig.ClusterResourceConflictPolicy):
-            Defines the behavior for handling the situation where
-            cluster-scoped resources being restored already exist in the
-            target cluster. This MUST be set to a value other than
-            CLUSTER_RESOURCE_CONFLICT_POLICY_UNSPECIFIED if
+            Optional. Defines the behavior for handling the situation
+            where cluster-scoped resources being restored already exist
+            in the target cluster. This MUST be set to a value other
+            than CLUSTER_RESOURCE_CONFLICT_POLICY_UNSPECIFIED if
             [cluster_resource_restore_scope][google.cloud.gkebackup.v1.RestoreConfig.cluster_resource_restore_scope]
             is not empty.
         namespaced_resource_restore_mode (google.cloud.gke_backup_v1.types.RestoreConfig.NamespacedResourceRestoreMode):
-            Defines the behavior for handling the situation where sets
-            of namespaced resources being restored already exist in the
-            target cluster. This MUST be set to a value other than
-            NAMESPACED_RESOURCE_RESTORE_MODE_UNSPECIFIED.
+            Optional. Defines the behavior for handling the situation
+            where sets of namespaced resources being restored already
+            exist in the target cluster. This MUST be set to a value
+            other than NAMESPACED_RESOURCE_RESTORE_MODE_UNSPECIFIED.
         cluster_resource_restore_scope (google.cloud.gke_backup_v1.types.RestoreConfig.ClusterResourceRestoreScope):
-            Identifies the cluster-scoped resources to
-            restore from the Backup. Not specifying it means
-            NO cluster resource will be restored.
+            Optional. Identifies the cluster-scoped
+            resources to restore from the Backup. Not
+            specifying it means NO cluster resource will be
+            restored.
         all_namespaces (bool):
             Restore all namespaced resources in the
             Backup if set to "True". Specifying this field
@@ -267,42 +267,60 @@ class RestoreConfig(proto.Message):
             all the resources to which they refer will be
             restored.
 
+            This field is a member of `oneof`_ ``namespaced_resource_restore_scope``.
+        no_namespaces (bool):
+            Do not restore any namespaced resources if
+            set to "True". Specifying this field to "False"
+            is not allowed.
+
+            This field is a member of `oneof`_ ``namespaced_resource_restore_scope``.
+        excluded_namespaces (google.cloud.gke_backup_v1.types.Namespaces):
+            A list of selected namespaces excluded from
+            restoration. All namespaces except those in this
+            list will be restored.
+
             This field is a member of `oneof`_ ``namespaced_resource_restore_scope``.
         substitution_rules (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.SubstitutionRule]):
-            A list of transformation rules to be applied
-            against Kubernetes resources as they are
-            selected for restoration from a Backup. Rules
-            are executed in order defined - this order
+            Optional. A list of transformation rules to
+            be applied against Kubernetes resources as they
+            are selected for restoration from a Backup.
+            Rules are executed in order defined - this order
             matters, as changes made by a rule may impact
             the filtering logic of subsequent rules. An
             empty list means no substitution will occur.
+        transformation_rules (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.TransformationRule]):
+            Optional. A list of transformation rules to
+            be applied against Kubernetes resources as they
+            are selected for restoration from a Backup.
+            Rules are executed in order defined - this order
+            matters, as changes made by a rule may impact
+            the filtering logic of subsequent rules. An
+            empty list means no transformation will occur.
     """
 
     class VolumeDataRestorePolicy(proto.Enum):
-        r"""Defines how volume data should be restored
+        r"""Defines how volume data should be restored.
 
         Values:
             VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED (0):
                 Unspecified (illegal).
             RESTORE_VOLUME_DATA_FROM_BACKUP (1):
-                For each PVC to be restored, will create a
-                new underlying volume (and PV) from the
-                corresponding VolumeBackup contained within the
-                Backup.
+                For each PVC to be restored, create a new
+                underlying volume and PV from the corresponding
+                VolumeBackup contained within the Backup.
             REUSE_VOLUME_HANDLE_FROM_BACKUP (2):
                 For each PVC to be restored, attempt to reuse
                 the original PV contained in the Backup (with
-                its original underlying volume).  Note that
-                option is likely only usable when restoring a
-                workload to its original cluster.
+                its original underlying volume). This option is
+                likely only usable when restoring a workload to
+                its original cluster.
             NO_VOLUME_DATA_RESTORATION (3):
-                For each PVC to be restored, PVCs will be
-                created without any particular action to restore
-                data.  In this case, the normal Kubernetes
-                provisioning logic would kick in, and this would
-                likely result in either dynamically provisioning
-                blank PVs or binding to statically provisioned
-                PVs.
+                For each PVC to be restored, create PVC
+                without any particular action to restore data.
+                In this case, the normal Kubernetes provisioning
+                logic would kick in, and this would likely
+                result in either dynamically provisioning blank
+                PVs or binding to statically provisioned PVs.
         """
         VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED = 0
         RESTORE_VOLUME_DATA_FROM_BACKUP = 1
@@ -323,11 +341,11 @@ class RestoreConfig(proto.Message):
                 resource.
             USE_BACKUP_VERSION (2):
                 Delete the existing version before
-                re-creating it from the Backup. Note that this
-                is a dangerous option which could cause
-                unintentional data loss if used inappropriately
-                - for example, deleting a CRD will cause
-                Kubernetes to delete all CRs of that type.
+                re-creating it from the Backup. This is a
+                dangerous option which could cause unintentional
+                data loss if used inappropriately. For example,
+                deleting a CRD will cause Kubernetes to delete
+                all CRs of that type.
         """
         CLUSTER_RESOURCE_CONFLICT_POLICY_UNSPECIFIED = 0
         USE_EXISTING_VERSION = 1
@@ -375,12 +393,15 @@ class RestoreConfig(proto.Message):
 
         Attributes:
             resource_group (str):
-                API group string of a Kubernetes resource,
-                e.g. "apiextensions.k8s.io", "storage.k8s.io",
-                etc. Note: use empty string for core API group
+                Optional. API group string of a Kubernetes
+                resource, e.g. "apiextensions.k8s.io",
+                "storage.k8s.io", etc. Note: use empty string
+                for core API group
             resource_kind (str):
-                Kind of a Kubernetes resource, e.g.
-                "CustomResourceDefinition", "StorageClass", etc.
+                Optional. Kind of a Kubernetes resource, must
+                be in UpperCamelCase (PascalCase) and singular
+                form. E.g. "CustomResourceDefinition",
+                "StorageClass", etc.
         """
 
         resource_group: str = proto.Field(
@@ -393,17 +414,50 @@ class RestoreConfig(proto.Message):
         )
 
     class ClusterResourceRestoreScope(proto.Message):
-        r"""Identifies the cluster-scoped resources to restore from the
-        Backup.
+        r"""Defines the scope of cluster-scoped resources to restore.
+
+        Some group kinds are not reasonable choices for a restore, and
+        will cause an error if selected here. Any scope selection that
+        would restore "all valid" resources automatically excludes these
+        group kinds.
+        - gkebackup.gke.io/BackupJob
+        - gkebackup.gke.io/RestoreJob
+        - metrics.k8s.io/NodeMetrics
+        - migration.k8s.io/StorageState
+        - migration.k8s.io/StorageVersionMigration
+        - Node
+        - snapshot.storage.k8s.io/VolumeSnapshotContent
+        - storage.k8s.io/CSINode
+
+        Some group kinds are driven by restore configuration elsewhere,
+        and will cause an error if selected here.
+        - Namespace
+        - PersistentVolume
 
         Attributes:
             selected_group_kinds (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.GroupKind]):
-                A list of "types" of cluster-scoped resources
-                to be restored from the Backup.  An empty list
-                means that NO cluster-scoped resources will be
-                restored. Note that Namespaces and
-                PersistentVolume restoration is handled
-                separately and is not governed by this field.
+                Optional. A list of cluster-scoped resource
+                group kinds to restore from the backup. If
+                specified, only the selected resources will be
+                restored. Mutually exclusive to any other field
+                in the message.
+            excluded_group_kinds (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.GroupKind]):
+                Optional. A list of cluster-scoped resource
+                group kinds to NOT restore from the backup. If
+                specified, all valid cluster-scoped resources
+                will be restored except for those specified in
+                the list. Mutually exclusive to any other field
+                in the message.
+            all_group_kinds (bool):
+                Optional. If True, all valid cluster-scoped
+                resources will be restored. Mutually exclusive
+                to any other field in the message.
+            no_group_kinds (bool):
+                Optional. If True, no cluster-scoped
+                resources will be restored. This has the same
+                restore scope as if the message is not defined.
+                Mutually exclusive to any other field in the
+                message.
         """
 
         selected_group_kinds: MutableSequence[
@@ -413,6 +467,21 @@ class RestoreConfig(proto.Message):
             number=1,
             message="RestoreConfig.GroupKind",
         )
+        excluded_group_kinds: MutableSequence[
+            "RestoreConfig.GroupKind"
+        ] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message="RestoreConfig.GroupKind",
+        )
+        all_group_kinds: bool = proto.Field(
+            proto.BOOL,
+            number=3,
+        )
+        no_group_kinds: bool = proto.Field(
+            proto.BOOL,
+            number=4,
+        )
 
     class SubstitutionRule(proto.Message):
         r"""A transformation rule to be applied against Kubernetes
@@ -422,23 +491,25 @@ class RestoreConfig(proto.Message):
 
         Attributes:
             target_namespaces (MutableSequence[str]):
-                (Filtering parameter) Any resource subject to
-                substitution must be contained within one of the
-                listed Kubernetes Namespace in the Backup. If
-                this field is not provided, no namespace
-                filtering will be performed (all resources in
-                all Namespaces, including all cluster-scoped
-                resources, will be candidates for substitution).
+                Optional. (Filtering parameter) Any resource
+                subject to substitution must be contained within
+                one of the listed Kubernetes Namespace in the
+                Backup. If this field is not provided, no
+                namespace filtering will be performed (all
+                resources in all Namespaces, including all
+                cluster-scoped resources, will be candidates for
+                substitution).
                 To mix cluster-scoped and namespaced resources
                 in the same rule, use an empty string ("") as
                 one of the target namespaces.
             target_group_kinds (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.GroupKind]):
-                (Filtering parameter) Any resource subject to
-                substitution must belong to one of the listed
-                "types". If this field is not provided, no type
-                filtering will be performed (all resources of
-                all types matching previous filtering parameters
-                will be candidates for substitution).
+                Optional. (Filtering parameter) Any resource
+                subject to substitution must belong to one of
+                the listed "types". If this field is not
+                provided, no type filtering will be performed
+                (all resources of all types matching previous
+                filtering parameters will be candidates for
+                substitution).
             target_json_path (str):
                 Required. This is a [JSONPath]
                 (https://kubernetes.io/docs/reference/kubectl/jsonpath/)
@@ -449,7 +520,8 @@ class RestoreConfig(proto.Message):
                 identifier (identifies exactly which fields out of the
                 candidate resources will be modified).
             original_value_pattern (str):
-                (Filtering parameter) This is a [regular expression]
+                Optional. (Filtering parameter) This is a [regular
+                expression]
                 (https://en.wikipedia.org/wiki/Regular_expression) that is
                 compared against the fields matched by the target_json_path
                 expression (and must also have passed the previous filters).
@@ -457,14 +529,14 @@ class RestoreConfig(proto.Message):
                 value does not match this expression. If this field is NOT
                 specified, then ALL fields matched by the target_json_path
                 expression will undergo substitution. Note that an empty
-                (e.g., "", rather than unspecified) value for for this field
+                (e.g., "", rather than unspecified) value for this field
                 will only match empty fields.
             new_value (str):
-                This is the new value to set for any fields
-                that pass the filtering and selection criteria.
-                To remove a value from a Kubernetes resource,
-                either leave this field unspecified, or set it
-                to the empty string ("").
+                Optional. This is the new value to set for
+                any fields that pass the filtering and selection
+                criteria. To remove a value from a Kubernetes
+                resource, either leave this field unspecified,
+                or set it to the empty string ("").
         """
 
         target_namespaces: MutableSequence[str] = proto.RepeatedField(
@@ -491,6 +563,187 @@ class RestoreConfig(proto.Message):
             number=5,
         )
 
+    class TransformationRuleAction(proto.Message):
+        r"""TransformationRuleAction defines a TransformationRule action
+        based on the JSON Patch RFC
+        (https://www.rfc-editor.org/rfc/rfc6902)
+
+        Attributes:
+            op (google.cloud.gke_backup_v1.types.RestoreConfig.TransformationRuleAction.Op):
+                Required. op specifies the operation to
+                perform.
+            from_path (str):
+                Optional. A string containing a JSON Pointer
+                value that references the location in the target
+                document to move the value from.
+            path (str):
+                Optional. A string containing a JSON-Pointer
+                value that references a location within the
+                target document where the operation is
+                performed.
+            value (str):
+                Optional. A string that specifies the desired
+                value in string format to use for
+                transformation.
+        """
+
+        class Op(proto.Enum):
+            r"""Possible values for operations of a transformation rule
+            action.
+
+            Values:
+                OP_UNSPECIFIED (0):
+                    Unspecified operation
+                REMOVE (1):
+                    The "remove" operation removes the value at
+                    the target location.
+                MOVE (2):
+                    The "move" operation removes the value at a
+                    specified location and adds it to the target
+                    location.
+                COPY (3):
+                    The "copy" operation copies the value at a
+                    specified location to the target location.
+                ADD (4):
+                    The "add" operation performs one of the
+                    following functions, depending upon what the
+                    target location references:
+
+                    1. If the target location specifies an array
+                        index, a new value is inserted into the
+                        array at the specified index.
+                    2. If the target location specifies an object
+                        member that does not already exist, a new
+                        member is added to the object.
+                    3. If the target location specifies an object
+                        member that does exist, that member's value
+                        is replaced.
+                TEST (5):
+                    The "test" operation tests that a value at
+                    the target location is equal to a specified
+                    value.
+                REPLACE (6):
+                    The "replace" operation replaces the value at
+                    the target location with a new value.  The
+                    operation object MUST contain a "value" member
+                    whose content specifies the replacement value.
+            """
+            OP_UNSPECIFIED = 0
+            REMOVE = 1
+            MOVE = 2
+            COPY = 3
+            ADD = 4
+            TEST = 5
+            REPLACE = 6
+
+        op: "RestoreConfig.TransformationRuleAction.Op" = proto.Field(
+            proto.ENUM,
+            number=1,
+            enum="RestoreConfig.TransformationRuleAction.Op",
+        )
+        from_path: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        path: str = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        value: str = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+
+    class ResourceFilter(proto.Message):
+        r"""ResourceFilter specifies matching criteria to limit the scope
+        of a change to a specific set of kubernetes resources that are
+        selected for restoration from a backup.
+
+        Attributes:
+            namespaces (MutableSequence[str]):
+                Optional. (Filtering parameter) Any resource
+                subject to transformation must be contained
+                within one of the listed Kubernetes Namespace in
+                the Backup. If this field is not provided, no
+                namespace filtering will be performed (all
+                resources in all Namespaces, including all
+                cluster-scoped resources, will be candidates for
+                transformation).
+            group_kinds (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.GroupKind]):
+                Optional. (Filtering parameter) Any resource
+                subject to transformation must belong to one of
+                the listed "types". If this field is not
+                provided, no type filtering will be performed
+                (all resources of all types matching previous
+                filtering parameters will be candidates for
+                transformation).
+            json_path (str):
+                Optional. This is a [JSONPath]
+                (https://github.com/json-path/JsonPath/blob/master/README.md)
+                expression that matches specific fields of candidate
+                resources and it operates as a filtering parameter
+                (resources that are not matched with this expression will
+                not be candidates for transformation).
+        """
+
+        namespaces: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
+        group_kinds: MutableSequence["RestoreConfig.GroupKind"] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message="RestoreConfig.GroupKind",
+        )
+        json_path: str = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+
+    class TransformationRule(proto.Message):
+        r"""A transformation rule to be applied against Kubernetes
+        resources as they are selected for restoration from a Backup. A
+        rule contains both filtering logic (which resources are subject
+        to transform) and transformation logic.
+
+        Attributes:
+            field_actions (MutableSequence[google.cloud.gke_backup_v1.types.RestoreConfig.TransformationRuleAction]):
+                Required. A list of transformation rule
+                actions to take against candidate resources.
+                Actions are executed in order defined - this
+                order matters, as they could potentially
+                interfere with each other and the first
+                operation could affect the outcome of the second
+                operation.
+            resource_filter (google.cloud.gke_backup_v1.types.RestoreConfig.ResourceFilter):
+                Optional. This field is used to specify a set
+                of fields that should be used to determine which
+                resources in backup should be acted upon by the
+                supplied transformation rule actions, and this
+                will ensure that only specific resources are
+                affected by transformation rule actions.
+            description (str):
+                Optional. The description is a user specified
+                string description of the transformation rule.
+        """
+
+        field_actions: MutableSequence[
+            "RestoreConfig.TransformationRuleAction"
+        ] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=1,
+            message="RestoreConfig.TransformationRuleAction",
+        )
+        resource_filter: "RestoreConfig.ResourceFilter" = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message="RestoreConfig.ResourceFilter",
+        )
+        description: str = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+
     volume_data_restore_policy: VolumeDataRestorePolicy = proto.Field(
         proto.ENUM,
         number=1,
@@ -528,11 +781,27 @@ class RestoreConfig(proto.Message):
         oneof="namespaced_resource_restore_scope",
         message=common.NamespacedNames,
     )
+    no_namespaces: bool = proto.Field(
+        proto.BOOL,
+        number=9,
+        oneof="namespaced_resource_restore_scope",
+    )
+    excluded_namespaces: common.Namespaces = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        oneof="namespaced_resource_restore_scope",
+        message=common.Namespaces,
+    )
     substitution_rules: MutableSequence[SubstitutionRule] = proto.RepeatedField(
         proto.MESSAGE,
         number=8,
         message=SubstitutionRule,
     )
+    transformation_rules: MutableSequence[TransformationRule] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=11,
+        message=TransformationRule,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
