@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -31,7 +33,7 @@ __protobuf__ = proto.module(
 class RestorePlan(proto.Message):
     r"""The configuration of a potential series of Restore operations
     to be performed against Backups belong to a particular
-    BackupPlan. Next id: 11
+    BackupPlan.
 
     Attributes:
         name (str):
@@ -48,8 +50,8 @@ class RestorePlan(proto.Message):
             Output only. The timestamp when this
             RestorePlan resource was last updated.
         description (str):
-            User specified descriptive string for this
-            RestorePlan.
+            Optional. User specified descriptive string
+            for this RestorePlan.
         backup_plan (str):
             Required. Immutable. A reference to the
             [BackupPlan][google.cloud.gkebackup.v1.BackupPlan] from
@@ -68,7 +70,8 @@ class RestorePlan(proto.Message):
             Required. Configuration of Restores created
             via this RestorePlan.
         labels (MutableMapping[str, str]):
-            A set of custom labels supplied by user.
+            Optional. A set of custom labels supplied by
+            user.
         etag (str):
             Output only. ``etag`` is used for optimistic concurrency
             control as a way to help prevent simultaneous updates of a
@@ -80,8 +83,39 @@ class RestorePlan(proto.Message):
             put that etag in the request to ``UpdateRestorePlan`` or
             ``DeleteRestorePlan`` to ensure that their change will be
             applied to the same version of the resource.
+        state (google.cloud.gke_backup_v1.types.RestorePlan.State):
+            Output only. State of the RestorePlan. This
+            State field reflects the various stages a
+            RestorePlan can be in during the Create
+            operation.
+        state_reason (str):
+            Output only. Human-readable description of why RestorePlan
+            is in the current ``state``
     """
 
+    class State(proto.Enum):
+        r"""State
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Default first value for Enums.
+            CLUSTER_PENDING (1):
+                Waiting for cluster state to be RUNNING.
+            READY (2):
+                The RestorePlan has successfully been created
+                and is ready for Restores.
+            FAILED (3):
+                RestorePlan creation has failed.
+            DELETING (4):
+                The RestorePlan is in the process of being
+                deleted.
+        """
+        STATE_UNSPECIFIED = 0
+        CLUSTER_PENDING = 1
+        READY = 2
+        FAILED = 3
+        DELETING = 4
+
     name: str = proto.Field(
         proto.STRING,
         number=1,
@@ -126,6 +160,15 @@ class RestorePlan(proto.Message):
         proto.STRING,
         number=10,
     )
+    state: State = proto.Field(
+        proto.ENUM,
+        number=11,
+        enum=State,
+    )
+    state_reason: str = proto.Field(
+        proto.STRING,
+        number=12,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
